#! /bin/env python

#programmed by Dalton Wu
#7-13-09
#The purpose of the program is to read in a Buddy.txt file containing
#2 columns of antennae that are paired and output a txt file that
#has 3 columns: index, CARMA baseline, and SZA baseline
#The CARMA baseline column contains all baselines for CARMA antennae
#(for the ones that have SZA buddies)
#The SZA baseline column contains all baselines for matching SZA antennae.
#To run the program type:
#% python baselinematch.py

def baselineMatch(array, foutput):
    """
        The purpose of this function is to take one file containing 2 columns of paired antennae, (CARMA and its SZA)
    and to output a file containing all of the CARMA baselines paired with the SZA baselines
    
    Input:
    array: A string representing the array and year of the project. For example: "a09"
    
    Output:
    foutput: The name of the file that the paired CARMA and SZA baselines will be written to
    """
    
    import carmatable as ct
    tableIn = ct.CarmaTable()
    tableIn.open(array + ".buddy")
    carmaAnts = tableIn.getCol(0)
    szaAnts = tableIn.getCol(1)
    carmaBaselines = []
    szaBaselines = []

    count = 1
    while (len(carmaAnts) > 0):
        while (count < len(carmaAnts)):
            stringAnt = carmaAnts[0] + "-" + carmaAnts[count] #always take the first one in the list, and match with all the rest
            carmaBaselines.append(stringAnt)
            count = count + 1
        count = 1
        del carmaAnts[0] #then take out the first one in the list, so that the next one in line will be matched will all the others
    #while there are still antenna numbers in the CARMA list 

    count = 1
    while (len(szaAnts) > 0):
        while (count < len(szaAnts)):
            stringAnt = szaAnts[0] + "-" + szaAnts[count]
            szaBaselines.append(stringAnt)
            count = count + 1
        count = 1
        del szaAnts[0]
    #do the same for the SZA list

    ####Outputting with Carma Table
    names = ["index","CARMA","SZA"]
    types = ["i","s","s"]
    units = ["","",""]
    tableOut = ct.CarmaTable(names,types,units)
    count = 0
    for (cLine,sLine) in zip(carmaBaselines,szaBaselines):
        tableOut.addRow([count,cLine,sLine])
        count = count + 1
    tableOut.write(foutput)
    #for each baseline in CARMA baseline list and SZA baseline list, write out to output file

#baselineMatch("a09", "baseline.txt")
#baselineMatch("BuddyB.txt", "baselineB.txt")
